#!/bin/ksh
#
#######################################################################
#UNIX SHELL program to start NetView for OS/390 snmpsrvr              #
#######################################################################
# Licensed Materials - Property of Tivoli Systems                     #
# 5697-ENV (c) Copyright Tivoli Systems 1999                          #
# All rights reserved.                                                #
#                                                                     #
# US Government Users Restricted Rights - Use, duplication or         #
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.   #
#######################################################################
#######################################################################
#
##Shell Switches
##
##uncomment following set -x command for debug pupose
#set -x
set -e

#######################################################################
# Exit prematurely
#######################################################################
exit1()
{
  echo "$0 exiting prematurely..."
  exit 1
}

#######################################################################
# The default port for snmpserver is 10010.  If you change web.xml to a 
# different SnmpServerPort change the following line.
#######################################################################
SNMPSERVER_OPTIONS="--port 10010 --logconfig ./logs/snmpserver-log4j.properties"

PRODUCT="NetView for OS/390"
PRODDIR=${NETVIEW_HOME}/jars
PRODZIP=$PRODDIR/snmpserver.jar
NWAYZIP=$NV390_PREVAR

DEFMX="-mx32M"
#######################################################################
##For below JDKOPT you may set "-v"
#######################################################################

JDKOPT=""
colon=":"

JAVA_HOME=${NETVIEW_HOME}/jvm/jre
JAVA=${JAVA_HOME}/bin/java

if [ ! -x "$JAVA" ] ; then
    echo "Unable to find: $JAVA."
    exit1
fi

JDKCLASSPATH=$JAVA_HOME

if [ ! -r "$PRODZIP" ]; then
    echo "Problem with the $PRODUCT installation."
    echo "Unable to find: $PRODZIP."
    exit 1
fi

if [ "" != "$NWAYZIP" ]; then
  if [ ! -r "$NWAYZIP" ]; then
      echo "Problem with the $PRODUCT environment variable NV390_PREVAR."
      echo "Unable to find: $NWAYZIP."
      exit 1
  fi
fi

#######################################################################
# Process arguments
#
#echo "cmd="$0 "arguments="$*
#######################################################################

otheropt=""
for arg in $*
do
   case $arg in
      -mx*)
         mxopt=$arg
         ;;
      -ms*)
         msopt=$arg
         ;;
      *)
         otheropt="$otheropt $arg"
         ;;
   esac
done

#######################################################################
# Setting default arguments
#######################################################################
if [ "" = "$mxopt" ]; then
	mxopt=$DEFMX
fi

#######################################################################
#echo $mxopt $msopt $otheropt
#
# Now build the command echo it & then execute
#
#    $JDKOPT     may need
#######################################################################
if [ "" != "$NWAYZIP" ]; then
   CMDSTR="$JDKJAVA -classpath \
	$NWAYZIP$colon$PRODZIP:$JDKCLASSPATH \ $msopt $mxopt \
        snmpserver.jar  $SNMPSERVER_OPTIONS  $otheropt"
else
   cd ${PRODDIR}
   CMDSTR="$JAVA -classpath \
	$PRODZIP:$JDKCLASSPATH:$CLASSPATH \
        $JDKOPT $msopt $mxopt -DNV_RELEASE=NETVIEW_H -jar \
        snmpserver.jar  $SNMPSERVER_OPTIONS $otheropt"
fi
echo $CMDSTR
exec  ${CMDSTR}
exit 0
